@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Id: bool.h 59 2009-07-18 17:31:50Z Michael.McTernan $
+ * $Id: bool.h 115 2010-08-19 09:58:45Z Michael.McTernan $
  *
  * Boolean type for msclib.
  * Copyright (C) 2009 Michael C McTernan, Michael.McTernan.2001@cs.bris.ac.uk
@@ -20,7 +20,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  ***************************************************************************/
 
-#if !defined(BOOL_H)
+#ifndef BOOL_H
 #define BOOL_H
 
 typedef enum
@@ -31,6 +31,6 @@ typedef enum
 Boolean;
 
 
-#endif
+#endif /* BOOL_H */
 
 /* END OF FILE */
